@@ -18,7 +18,8 @@
 #define LBA_SIZE 512u
 #define MBR_SIZE (LBA_SIZE - MBR_OFFSET)
 
-static const unsigned char GPT_PROTECTIVE_MBR[LBA_SIZE - MBR_OFFSET] =
+static const unsigned char __attribute__ ((nonstring))
+GPT_PROTECTIVE_MBR[LBA_SIZE - MBR_OFFSET] =
  "\x00\x00\x00\x00\x00\x00"  // 6 bytes of zeros
  "\x80"                      // bootable (violation of GPT spec, but some
                              //  BIOS/MBR *and* UEFI won't boot otherwise)
@@ -32,7 +33,8 @@ static const unsigned char GPT_PROTECTIVE_MBR[LBA_SIZE - MBR_OFFSET] =
  "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
  "\x55\xaa";                 // MBR signature
 
-static const unsigned char gpt_signature[8] =
+static const unsigned char __attribute__ ((nonstring))
+gpt_signature[8] =
  "\x45\x46\x49\x20\x50\x41\x52\x54";
 
 uint32_t host_to_le32(uint32_t x){
@@ -338,7 +340,6 @@ static void *
 const_map_gpt(const device *d, size_t *mapsize, int *fd, size_t lbasize){
   const int pgsize = getpagesize();
   const unsigned gptlbas = 1 + (MINIMUM_GPT_ENTRIES * sizeof(struct gpt_entry) / lbasize);
-  uint64_t off;
   void *map;
 
   if(pgsize < 0){
@@ -351,7 +352,7 @@ const_map_gpt(const device *d, size_t *mapsize, int *fd, size_t lbasize){
   }
   // The first copy goes into LBA 1. Calculate offset into map due to
   // lbasize possibly (probably) not equalling the page size.
-  if((off = lbasize % pgsize) == 0){
+  if(lbasize % pgsize == 0){
     *mapsize = 0;
   }else{
     *mapsize = lbasize;
@@ -380,7 +381,6 @@ static void *
 map_gpt(device *d, size_t *mapsize, int *fd, size_t lbasize){
   const int pgsize = getpagesize();
   const unsigned gptlbas = 1 + (MINIMUM_GPT_ENTRIES * sizeof(struct gpt_entry) / lbasize);
-  uint64_t off;
   void *map;
 
   if(pgsize < 0){
@@ -397,7 +397,7 @@ map_gpt(device *d, size_t *mapsize, int *fd, size_t lbasize){
   }
   // The first copy goes into LBA 1. Calculate offset into map due to
   // lbasize possibly (probably) not equalling the page size.
-  if((off = lbasize % pgsize) == 0){
+  if(lbasize % pgsize == 0){
     *mapsize = 0;
   }else{
     *mapsize = lbasize;
