@@ -1,4 +1,4 @@
-// copyright 2012–2020 nick black
+// copyright 2012–2021 nick black
 #ifndef GROWLIGHT_PTYPES
 #define GROWLIGHT_PTYPES
 
@@ -16,7 +16,8 @@ extern "C" {
 typedef struct ptype {
 	uint16_t code;			// [fg]disk/parted code (2 bytes)
 	const char *name;		// Human-readable name
-	uint8_t gpt_guid[GUIDSIZE];	// GPT Type GUID (16 bytes) or 0s
+	// GPT Type GUID (16 bytes) or 0s
+	uint8_t gpt_guid[GUIDSIZE] __attribute__ ((nonstring));
 	uint8_t mbr_code;		// MBR code (1 byte) or 0
 	unsigned aggregable;		// Can it go into an aggregate?
 } ptype;
